kopsa

package module
v0.0.0-...-33789fe Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 3, 2015 License: MIT Imports: 4 Imported by: 2

README

kopsa

Drop-in file copying module

Usage

Get it: go get github.com/Varjelus/kopsa

Import it: import github.com/Varjelus/kopsa

Use it

bytesCopied, err := kopsa.Copy("destination.txt", "source.txt"), handle error

or ... kopsa.Copy("destination.txt", "source1.txt", "source2.txt", "source3.txt") ...

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Copy

func Copy(dst string, srcs ...string) (int64, error)

Copy takes a destination path as the first argument and any number of additional string arguments to be used as copy source paths.

func SetBufferSize

func SetBufferSize(size int)

SetBufferSize sets the buffer size used in copying

Types

This section is empty.

Jump to