Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Copy ¶
Copy takes a destination path as the first argument and any number of additional string arguments to be used as copy source paths.
func SetBufferSize ¶
func SetBufferSize(size int)
SetBufferSize sets the buffer size used in copying
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.